# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.7.0 - 2024-03-25

### Added

- This changelog! It's never too late, right?!

### Changed

- Show the list's actual filename in "Edit" menu item instead of hard-coded
  `todo.txt`. ([PR #6](https://github.com/keithfancher/Todo-Indicator/pull/6).)
- Update module structure for proper packaging and installation.
- Update build system and package metadata.
- Documentation updates: bring things into the current century, mostly.

## 0.6.0 - 2022-10-17

### Added

- Python 3 support. ([PR #5](https://github.com/keithfancher/Todo-Indicator/pull/5).)

### Fixed

- A few under-the-hood updates to how we import our dependencies. Un-break
  things in more modern distros.

## 0.5.0 - 2014-04-30

## 0.4.0 - 2014-04-17

## 0.3.0 - 2013-03-01

## 0.2.0 - 2013-02-05

## 0.1.0 - 2012-10-07
